Session class
Constructors
- Session()
Properties
- authenticationType ↔ AuthenticationType
-
getter/setter pair
-
getter/setter pair
- creation ↔ DateTime
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- id ↔ DC?
-
getter/setter pair
-
localHeaders
↔ Map<
UInt8, dynamic> -
getter/setter pair
- localMethod ↔ AuthenticationMethod
-
getter/setter pair
- modification ↔ DateTime
-
getter/setter pair
-
remoteHeaders
↔ Map<
UInt8, dynamic> -
getter/setter pair
- remoteMethod ↔ AuthenticationMethod
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
variables
→ KeyList<
String, dynamic> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited