UInt32 class

Inheritance

Constructors

UInt32(int value)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNum() int
inherited
toString() String
A string representation of this object.
inherited

Operators

operator +(IntType<int> other) IntType<int>
inherited
operator -(IntType<int> other) IntType<int>
inherited
operator <(IntType<num> other) bool
inherited
operator <=(IntType<num> other) bool
inherited
operator ==(Object other) bool
The equality operator.
inherited
operator >(IntType<num> other) bool
inherited
operator >=(IntType<num> other) bool
inherited